@@ -463,6 +463,7 @@ def gdalenv(request):
         if rasterio.env.local._env:
             rasterio.env.delenv()
             rasterio.env.local._env = None
+
     request.addfinalizer(fin)
 
 
@@ -487,6 +488,11 @@ def path_rgb_msk_byte_tif(data_dir):
     return os.path.join(data_dir, 'RGB2.byte.tif')
 
 
+@pytest.fixture(scope='session')
+def path_cogeo_tif(data_dir):
+    return os.path.join(data_dir, 'cogeo.tif')
+
+
 @pytest.fixture(scope='function')
 def _path_multiband_no_colorinterp(tmpdir):
 
